import { z } from 'zod';
import { HttpClient } from '@wix/http-client';
import { logger } from '../infra/logger.js';
import { handleWixAPIResponse } from '../tool-utils.js';
import { isApiUrlAllowed } from './validation.js';
export function addApiCallTool(server, strategy, allowedTools = ['CallWixSiteAPI', 'ListWixSites', 'ManageWixSite']) {
    if (allowedTools.includes('CallWixSiteAPI')) {
        server.tool('CallWixSiteAPI', [
            'Call Wix apis on a business or site. Use this to create, read, update, and delete data and other Wix entities in your Wix site,',
            `You should ALWAYS check the rest docs - "SearchWixRESTDocumentation" for the specific API you want to call, don't just call it without knowing what it does, CHECK THE DOCS`,
            'Error Handling:',
            'If the error is related to missing installed app or "WDE0110: Wix Code not enabled", you should install the missing app by using ReadFullDocsArticle tool to fetch the article - https://dev.wix.com/docs/kb-only/MCP_REST_RECIPES_KB_ID/TRAIN_wix.devcenter.apps.installer.v1.AppsInstallerService.InstallApp',
            '**Note:** there is no need to check if an app is installed/ Wix Code enabled in advance, just call the API and handle the error if it occurs, the API error message will state it clearly.',
            'For any other error, use your default error handling mechanism'
        ].join('\n'), {
            siteId: z
                .string()
                .describe('The id of the site selected using site selection tool'),
            url: z
                .string()
                .url()
                .describe('The url of the api to call - ALWAYS get the information from the Wix REST docs or from the conversation context, the URL MUST BE ABSOLUTE URL'),
            method: z
                .string()
                .describe('The HTTP method to use for the API call (e.g. GET, POST, PUT, DELETE)'),
            body: z
                .string()
                .optional()
                .describe('A string representing of a valid JSON object to describe the body of the request')
        }, async ({ url, body, method, siteId }, { httpClient }) => {
            logger.log(`Calling Wix Site API: ${siteId} ${url}, body: ${JSON.stringify(body)}`);
            const { isAllowed, error: urlError } = isApiUrlAllowed(url);
            if (!isAllowed) {
                return {
                    content: [
                        {
                            isError: true,
                            type: 'text',
                            text: `Error validating URL: ${urlError}`
                        }
                    ]
                };
            }
            try {
                const response = await httpClient.request({
                    url,
                    method: method,
                    headers: {
                        ...(await strategy.getSiteAuthHeaders(siteId)),
                        ...(body ? { 'Content-Type': 'application/json' } : {})
                    },
                    data: method === 'GET' ? undefined : body
                });
                const responseData = await handleWixAPIResponse(response);
                return {
                    content: [
                        {
                            type: 'text',
                            text: `Wix Site API call successful: ${JSON.stringify(responseData)}`
                        }
                    ]
                };
            }
            catch (error) {
                let requestId;
                if (HttpClient.isHttpError(error)) {
                    requestId = error.requestId;
                }
                const errorMessage = `Failed to call Wix Site API: ${error} Request ID: ${requestId ? `Request ID: ${requestId}` : ''}`;
                logger.error(errorMessage);
                const response = error.response;
                if (!response) {
                    throw new Error(errorMessage);
                }
                return handleWixAPIResponse(response);
            }
        });
    }
    if (allowedTools.includes('ListWixSites')) {
        server.tool('ListWixSites', 'List Wix sites for the current user, by default it will return all sites, but you can filter by name', {
            nameSearch: z
                .string()
                .optional()
                .describe('optional filer by name, if not provided all sites will be returned'),
            // Hack for Cursor ignoring tools with no params (when nameSearch is optional)
            alwaysTrue: z.boolean().describe('Always pass true to this parameter')
        }, async ({ nameSearch }, { httpClient }) => {
            const sitesRes = await httpClient.post('https://www.wixapis.com/site-list/v2/sites/query', {
                query: {
                    cursorPaging: { limit: 21 },
                    filter: {
                        ...(nameSearch
                            ? {
                                name: nameSearch
                            }
                            : {}),
                        namespace: {
                            $in: ['WIX', 'DASHBOARD_FIRST', 'ANYWHERE', 'HEADLESS']
                        }
                    }
                }
            }, {
                headers: {
                    ...(await strategy.getAccountAuthHeaders()),
                    'Content-Type': 'application/json',
                    Accept: 'application/json, text/plain, */*'
                }
            });
            const result = sitesRes.data.sites?.map(({ id, displayName }) => ({
                id,
                name: displayName
            })) ?? [];
            return {
                content: [
                    {
                        type: 'text',
                        text: JSON.stringify(result)
                    },
                    {
                        type: 'text',
                        text: 'if there is more than one site returned, the user should pick one from a list, list the sites (only name) for the user and ask them to pick one,' +
                            'If more than 20 are found you should list all 20 and suggest to search by the name of the site they are looking for'
                    }
                ]
            };
        });
    }
    if (allowedTools.includes('ManageWixSite')) {
        server.tool('ManageWixSite', `Use account level API in order to create a site, update a site and publish site.
    ALWAYS use "SearchWixRESTDocumentation" to search for the API you should invoke, NEVER GUESS THE SITE API URL
    You should ALWAYS check the rest docs - "SearchWixRESTDocumentation" for the specific API you want to call, don't just call it without knowing what it does, CHECK THE DOCS`, {
            url: z
                .string()
                .url()
                .describe('The url of the api to call - ALWAYS get the information from the Wix REST docs DONT GUESS IT, the URL MUST BE ABSOLUTE URL'),
            method: z
                .string()
                .describe('The HTTP method to use for the API call (e.g. GET, POST, PUT, DELETE)'),
            body: z
                .string()
                .optional()
                .describe('A string representing of a valid JSON object to describe the body of the request')
        }, async ({ url, body, method }, { httpClient }) => {
            logger.log(`Calling Wix Account level API: ${url}, body: ${JSON.stringify(body)}`);
            const { isAllowed, error: urlError } = isApiUrlAllowed(url);
            if (!isAllowed) {
                return {
                    content: [
                        {
                            isError: true,
                            type: 'text',
                            text: `Error validating URL: ${urlError}`
                        }
                    ]
                };
            }
            try {
                // if we would like to allow the user to manage multiple accounts, we should add accountId to the params
                const response = await httpClient.request({
                    url,
                    method: method,
                    headers: {
                        ...(await strategy.getAccountAuthHeaders()),
                        ...(body ? { 'Content-Type': 'application/json' } : {})
                    },
                    data: method === 'GET' ? undefined : body
                });
                const responseData = await handleWixAPIResponse(response);
                return {
                    content: [
                        {
                            type: 'text',
                            text: `Wix Account API call successful: ${JSON.stringify(responseData)}`
                        }
                    ]
                };
            }
            catch (error) {
                logger.error(`Failed to call Wix Account API: ${error}`);
                const response = error.response;
                if (!response) {
                    throw new Error(`Failed to call Wix Account API: ${error}`);
                }
                return handleWixAPIResponse(response);
            }
        });
    }
}
//# sourceMappingURL=index.js.map