import './infra/sentry.js';
import minimist from 'minimist';
import { StdioServerTransport } from '@modelcontextprotocol/sdk/server/stdio.js';
import { addDocsTools, VALID_DOCS_TOOLS } from './docs/docs.js';
import { addCliTools, VALID_CLI_TOOLS } from './cli-tools/cli.js';
import { logger, attachStdErrLogger, attachMcpServerLogger, attachFileLogger } from './infra/logger.js';
import { WixMcpServer } from './wix-mcp-server.js';
import { addDocsResources } from './resources/docs.js';
import { addApiCallTool } from './api-call/index.js';
const PUBLIC_TOOLS = [...VALID_DOCS_TOOLS];
const EXPERIMENTAL_TOOLS = [
    'WIX_API',
    'CLI_COMMAND',
    'GET_TO_KNOW_WIX'
];
export const DEFAULT_TOOLS = [...VALID_DOCS_TOOLS];
const parsedArgs = minimist(process.argv.slice(2));
function parseExperimentalArg() {
    const experimentalArg = parsedArgs['experimental'];
    if (!experimentalArg)
        return [];
    return experimentalArg
        .split(',')
        .map((t) => t.trim())
        .filter((tool) => EXPERIMENTAL_TOOLS.includes(tool));
}
function parseWixAuthorizationArg() {
    return parsedArgs['wixAuthorization'];
}
function parseToolsArg() {
    const toolsArg = parsedArgs['tools'];
    const experimentalTools = parseExperimentalArg();
    if (!toolsArg) {
        // When no tools specified, return both default and experimental tools
        return [...DEFAULT_TOOLS, ...experimentalTools];
    }
    const requestedTools = toolsArg.split(',').map((t) => t.trim());
    const tools = [
        // Include valid non-experimental tools
        ...requestedTools.filter((tool) => PUBLIC_TOOLS.includes(tool)),
        // Include enabled experimental tools
        ...experimentalTools
    ];
    // Warn about enabled experimental tools
    tools.forEach((tool) => {
        if (EXPERIMENTAL_TOOLS.includes(tool)) {
            logger.log(`Warning: ${tool} is an experimental tool and may have limited functionality or breaking changes`);
        }
    });
    return tools;
}
const loggerType = parsedArgs['logger'] || 'mcp';
if (loggerType === 'file') {
    attachFileLogger();
}
else {
    // Initially we log to stderr, because MCP server is not connected yet
    // When the server is connected, we attach the MCP server logger
    attachStdErrLogger();
}
logger.log('--------------------------------');
logger.log('starting WIX MCP server');
logger.log('--------------------------------');
const server = new WixMcpServer({
    name: 'wix-mcp-server',
    version: '1.0.0'
}, {
    capabilities: {
        tools: {},
        prompts: {},
        logging: {},
        resources: {}
    }
});
const activeTools = parseToolsArg();
logger.log('Active tools:', activeTools);
const docsTools = activeTools.filter((tool) => VALID_DOCS_TOOLS.includes(tool));
if (docsTools.length > 0) {
    logger.log('Adding docs tools:', docsTools);
    addDocsTools(server, docsTools, activeTools.includes('GET_TO_KNOW_WIX'));
}
const isWixOne = parsedArgs['cli'] === 'wix-one';
const cliTools = activeTools.filter((tool) => VALID_CLI_TOOLS.includes(tool));
if (cliTools.length > 0) {
    logger.log('Adding cli tools:', cliTools, 'isWixOne:', isWixOne);
    addCliTools(server, cliTools, isWixOne);
    if (cliTools.includes('WIX_API')) {
        const wixAuthorization = parseWixAuthorizationArg();
        if (wixAuthorization) {
            logger.log('Using wixAuthorization argument for WIX_API');
            const cliAuthStrategy = {
                getSiteAuthHeaders: () => ({
                    Authorization: wixAuthorization
                }),
                getAccountAuthHeaders: () => ({
                    Authorization: wixAuthorization
                })
            };
            addApiCallTool(server, cliAuthStrategy, ['CallWixSiteAPI']);
        }
        else {
            logger.error('WIX_API tool requires missing wixAuthorization argument to be set. Will not add WIX_API tool.');
        }
    }
}
try {
    const portals = parsedArgs['portals']?.split(',') || [];
    if (portals.length > 0) {
        logger.log('Adding docs resources for portals:', portals);
        await addDocsResources(server, portals);
    }
}
catch (error) {
    logger.error('Error adding docs resources:', error);
}
logger.log('Starting server');
const transport = new StdioServerTransport();
logger.log('Connecting to transport');
await server.connect(transport);
logger.log('Transport connected');
if (loggerType === 'mcp') {
    // From now on, we log to the MCP server
    attachMcpServerLogger(server);
}
//# sourceMappingURL=bin.js.map