import { z } from 'zod';
import { logger } from '../infra/logger.js';
import { execa } from 'execa';
export const VALID_CLI_TOOLS = ['WIX_API', 'CLI_COMMAND'];
export function addCliTools(server, allowedTools = ['CLI_COMMAND'], isWixOne = false) {
    if (allowedTools.includes('CLI_COMMAND')) {
        server.tool('RunWixCliCommand', `Executes Wix CLI commands for Wix app development and management.
    Use this tool to run commands like 'wix app generate' (adds new extensions), 'wix app build' (builds your app), 'wix app preview' (creates shareable preview), 'wix app release' (releases a new version of your app), and more.

    IMPORTANT: Before using this tool, check if the command is mapped in package.json scripts:
    * Use this tool for npm/yarn scripts that map to Wix CLI commands as well.
    * Do not use this tool for starting the local development server.
    
    Before using this tool, you MUST search the Wix documentation for the command you want to run.
    
    DO NOT USE THIS TOOL FOR ANY OTHER PURPOSE. IT IS ONLY FOR WIX CLI COMMANDS.`, {
            appPath: z
                .string()
                .describe('The full path to the Wix CLI app to run the command on.'),
            extensionType: z
                .enum([
                'dashboard-page',
                'dashboard-plugin',
                'dashboard-menu-plugin',
                'dashboard-modal',
                'web-method',
                'api-route',
                'event',
                'service-plugin'
            ])
                .optional()
                .describe('The type of extension to generate. You MUST provide this for commands that generate extensions.'),
            extensionName: z
                .string()
                .optional()
                .describe('The name of the extension to generate, e.g. My Dashboard Page. You MUST provide this for commands that generate extensions.'),
            searchedDocs: z
                .boolean()
                .describe('Whether you have already searched the Wix documentation for the command you want to run.'),
            command: z
                .string()
                .min(1, 'Command cannot be empty')
                .max(1000, 'Command is too long')
                .describe("The Wix CLI command to execute (e.g. 'wix app generate', 'wix app build', 'wix app preview', 'wix app release', etc.), or a script that maps to a Wix CLI command (e.g. 'npm run generate', 'yarn generate', etc.).")
        }, async ({ command, appPath, extensionType, extensionName }) => {
            logger.log(`RunWixCliCommand: command: ${command}, appPath: ${appPath}, extensionType: ${extensionType}, extensionName: ${extensionName}`);
            let commandName = '';
            let commandArgs = [];
            if (command.includes('generate')) {
                if (!extensionType) {
                    return {
                        content: [
                            {
                                type: 'text',
                                text: "Error: You must provide an extension type for the 'generate' command."
                            }
                        ],
                        isError: true
                    };
                }
                if (!extensionName) {
                    return {
                        content: [
                            {
                                type: 'text',
                                text: "Error: You must provide an extension name for the 'generate' command."
                            }
                        ],
                        isError: true
                    };
                }
                // Format generate command with proper arguments
                commandName = 'npx';
                commandArgs = [
                    isWixOne ? 'wix-one' : 'wix',
                    'app',
                    'generate',
                    '-t',
                    extensionType,
                    '-n',
                    extensionName,
                    '--json'
                ];
            }
            else {
                const commandParts = command.split(' ');
                commandName = commandParts[0];
                commandArgs = commandParts.slice(1);
            }
            if (isWixOne && commandName === 'wix') {
                commandName = 'wix-one';
            }
            try {
                logger.log(`Executing Wix CLI command: ${commandName} ${commandArgs.join(' ')}`);
                // Execute with timeout
                const { stdout, stderr, exitCode } = await execa(commandName, commandArgs, {
                    cwd: appPath,
                    extendEnv: true,
                    env: {
                        ...process.env
                    },
                    timeout: 5 * 60 * 1000, // 5 minute timeout
                    maxBuffer: 10 * 1024 * 1024 // 10MB output limit
                });
                if (exitCode !== 0) {
                    return {
                        content: [{ type: 'text', text: `Error: ${stderr}` }],
                        isError: true
                    };
                }
                logger.log(`RunWixCliCommand: stdout: ${stdout}`);
                logger.log(`RunWixCliCommand: stderr: ${stderr}`);
                return {
                    content: [
                        { type: 'text', text: stdout },
                        ...(stderr
                            ? [{ type: 'text', text: `Error: ${stderr}` }]
                            : [])
                    ]
                };
            }
            catch (error) {
                logger.error(`Error executing Wix CLI command: ${error}`);
                return {
                    content: [{ type: 'text', text: `Error: ${error}` }],
                    isError: true
                };
            }
        });
    }
}
//# sourceMappingURL=cli.js.map