import { z } from 'zod';
import { runSemanticSearchAndFormat } from './semanticSearch.js';
import { logger } from '../infra/logger.js';
import { captureException } from '@sentry/node';
import { fetchArticleContent } from './fetch-article.js';
import { addGetToKnowTools, WixREADME_DEPENDENT_DESCRIPTION } from './get-to-know.js';
export const VALID_DOCS_TOOLS = [
    'WDS',
    'REST',
    'SDK',
    'BUILD_APPS',
    'WIX_HEADLESS',
    'BUSINESS_SOLUTIONS'
];
export const addDocsTools = (server, allowedTools = [
    'WDS',
    'REST',
    'SDK',
    'BUILD_APPS',
    'WIX_HEADLESS',
    'BUSINESS_SOLUTIONS'
], getToKnowWixEnabled = false) => {
    if (getToKnowWixEnabled) {
        addGetToKnowTools(server);
    }
    // WDS Documentation
    if (allowedTools.includes('WDS')) {
        server.tool('SearchWixWDSDocumentation', [
            'Searches the Wix Design System Documentation for components and patterns.',
            'Use this tool when you need to understand or implement UI components and design patterns in a Wix project.',
            'Search for specific component names, patterns, or UI requirements.',
            "If you can't find what you need, try to rephrase your search term or use bigger maxResults value.",
            getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term to search for in the Wix Design System Documentation'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(10)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Wix WDS`);
                const result = await runSemanticSearchAndFormat({
                    toolName: 'WDS',
                    toolParams: {
                        searchTerm: searchTerm
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15))
                });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchWixWDSDocumentation',
                        toolName: 'SearchWixWDSDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Wix WDS: ${error}`);
                return {
                    isError: true,
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    // REST Documentation
    if (allowedTools.includes('REST')) {
        server.tool('SearchWixRESTDocumentation', [
            'Searches the official Wix REST API documentation.',
            'Use this tool whenever you need to to interact with the Wix platform via HTTP requests.',
            "Specify the API endpoint, resource, or action you need information about (e.g., 'get site details endpoint', 'create data collection', 'update product API', 'REST authentication').",
            "If you can't find what you need, try to rephrase your search term or use bigger maxResults value.",
            getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term to search for in the Wix REST API Documentation'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(10)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Wix REST API`);
                const result = await runSemanticSearchAndFormat({
                    toolName: 'REST',
                    toolParams: {
                        searchTerm: searchTerm
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15)),
                    linesInEachResult: 15
                });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        },
                        {
                            type: 'text',
                            text: 'Next, you MUST use the ReadFullDocsArticle tool if you want to read the full documentation for a specific article or method.'
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchWixRESTDocumentation',
                        toolName: 'SearchWixRESTDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Wix REST API: ${error}`);
                return {
                    isError: true,
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    if (allowedTools.includes('BUSINESS_SOLUTIONS') && !getToKnowWixEnabled) {
        server.tool('WixBusinessFlowsDocumentation', [
            'This tool provides step-by-step recipes for setting up complex Wix business solutions that involve multiple API calls.',
            'It excels at guiding the creation of features like booking systems with payments.',
            'For example, it can guide the setup of a service in Wix Bookings where customers can pay using Wix Payments, such as creating a bookable yoga class',
            'It searches the Wix Business Solutions documentation for these integrated workflows involving services, bookings, payments, stores, blogs, and more.',
            'This tool returns a list of articles that are potentially relevant to the input search term.',
            '**IMPORTANT NOTES:**',
            '1. Before attempting to implement a multi step API calls on Wix, YOU MUST TRY THIS TOOL FIRST.',
            '2. Out of the returned list of articles that you will receive, you MUST select the most relevant one and use the ReadFullDocsArticle tool to fetch it.'
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term for the required sample flow (e.g. "setup a new business")'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(5)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Wix Sample Flows`);
                const result = await runSemanticSearchAndFormat({
                    toolName: 'BUSINESS_SOLUTIONS',
                    toolParams: {
                        searchTerm: '**RECIPE**:  Business Recipes - full setup flow for::: ' +
                            searchTerm
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15))
                });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        },
                        {
                            type: 'text',
                            text: `Out of the included list of articles, you **MUST** select the one that is most relevant to the user's request and use the ReadFullDocsArticle tool to fetch it.`
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchWixSampleFlowsDocumentation',
                        toolName: 'SearchWixSampleFlowsDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Wix Sample Flows: ${error}`);
                return {
                    isError: true,
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    // SDK Documentation
    if (allowedTools.includes('SDK')) {
        server.tool('SearchWixSDKDocumentation', [
            'Searches the official Wix javascript SDK documentation.',
            'Use this tool whenever you need to write or modify Wix related SDK code.',
            "Specify the SDK module, function, or feature you need information about (e.g., 'how to query all items from a data collection?', 'how to use wix-stores-backend', 'authentication methods in the SDK').",
            "If you can't find what you need, try to rephrase your search term or use bigger maxResults value.",
            getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term to search for in the Wix SDK Documentation'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(5)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Wix SDK`);
                panorama
                    .transaction('SearchWixSDKDocumentation')
                    .start({ maxResults });
                const result = await runSemanticSearchAndFormat({
                    toolName: 'SDK',
                    toolParams: {
                        searchTerm: searchTerm
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15)),
                    linesInEachResult: 15
                });
                panorama
                    .transaction('SearchWixSDKDocumentation')
                    .finish({ maxResults });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        },
                        {
                            type: 'text',
                            text: 'Next, you MUST use ReadFullDocsArticle tool if you want to read full documentation for a specific article or method.'
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchWixSDKDocumentation',
                        toolName: 'SearchWixSDKDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Wix SDK: ${error}`);
                return {
                    isError: true,
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    // Build Apps Documentation
    if (allowedTools.includes('BUILD_APPS')) {
        server.tool('SearchBuildAppsDocumentation', [
            'Searches the official Build Apps documentation.',
            'Use this tool when you need to understand or implement Wix CLI applications related code.',
            'The search term should be a specific Wix CLI command or specific topic related to Wix CLI applications or its ecosystem (e.g. deployment, creating new extensions etc).',
            "If you can't find what you need, try to rephrase your search term or use bigger maxResults value.",
            getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term to search for in the Build Apps Documentation'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(5)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Build Apps`);
                const result = await runSemanticSearchAndFormat({
                    toolName: 'BUILD_APPS',
                    toolParams: {
                        searchTerm: `wix cli docs for ${searchTerm}`
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15))
                });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchBuildAppsDocumentation',
                        toolName: 'SearchBuildAppsDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Build Apps: ${error}`);
                return {
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    // Wix Headless Documentation
    if (allowedTools.includes('WIX_HEADLESS')) {
        server.tool('SearchWixHeadlessDocumentation', [
            'Searches the official Wix Headless Documentation.',
            'Use this tool when you need to understand or implement Headless related code.',
            'The search term should be a specific Wix Headless topic or feature you need information about.',
            "If you can't find what you need, try to rephrase your search term or use bigger maxResults value.",
            getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
        ].join('\n'), {
            searchTerm: z
                .string()
                .describe('The search term to search for in the Headless Documentation'),
            maxResults: z
                .number()
                .describe('The maximum number of results to return, default is 5, max is 15')
                .min(1)
                .max(15)
                .optional()
                .default(5)
        }, async ({ searchTerm, maxResults }, { panorama }) => {
            try {
                logger.log(`Searching for ${searchTerm} in Headless`);
                const result = await runSemanticSearchAndFormat({
                    toolName: 'WIX_HEADLESS',
                    toolParams: {
                        searchTerm: searchTerm
                    },
                    maxResults: Math.max(1, Math.min(maxResults ?? 5, 15))
                });
                return {
                    content: [
                        {
                            type: 'text',
                            text: result
                        }
                    ]
                };
            }
            catch (error) {
                panorama.errorMonitor().reportError(error);
                captureException(error, {
                    tags: {
                        componentId: 'SearchWixHeadlessDocumentation',
                        toolName: 'SearchWixHeadlessDocumentation'
                    }
                });
                logger.error(`Error searching for ${searchTerm} in Wix Headless: ${error}`);
                return {
                    content: [{ type: 'text', text: 'Error: ' + error.message }]
                };
            }
        });
    }
    server.tool('ReadFullDocsArticle', [
        'Fetches the full Wix docs article or method article.',
        'Use this tool when you read a summary of a docs article or method article, you have the docs url and want to read the full article.',
        getToKnowWixEnabled ? WixREADME_DEPENDENT_DESCRIPTION : ''
    ].join('\n'), {
        articleUrl: z
            .string()
            .url()
            .describe('The URL of the docs article or method article to fetch. Should be something like https://dev.wix.com/docs/.../.../...')
    }, async ({ articleUrl }, { httpClient }) => {
        try {
            const articleContent = await fetchArticleContent(httpClient, articleUrl, 'article');
            if (!articleContent) {
                throw new Error('Article content is empty');
            }
            return {
                content: [
                    {
                        type: 'text',
                        text: articleContent
                    },
                    {
                        type: 'text',
                        text: [
                            '---',
                            'Next, if you are dealing with a method - you MUST call ReadFullDocsMethodSchema tool - it will give you the full request schema for the method.'
                        ].join('\n')
                    }
                ]
            };
        }
        catch (error) {
            logger.error(`Error fetching article content or method schema for ${articleUrl}: ${error}`);
            return {
                content: [
                    {
                        type: 'text',
                        text: `Could not fetch article content: "${error.message}". You should try completing the task without it.`
                    }
                ]
            };
        }
    });
    server.tool('ReadFullDocsMethodSchema', [
        'Fetches the full method schema for a given method. Always use it before calling the method.',
        'This will give you the entire request/response schema with all the fields and their descriptions.'
    ].join('\n'), {
        articleUrl: z
            .string()
            .url()
            .describe('The URL of the documentation to fetch. Should be something like https://dev.wix.com/docs/.../.../...')
    }, async ({ articleUrl }, { httpClient }) => {
        try {
            const articleContent = await fetchArticleContent(httpClient, articleUrl, 'methodSchema');
            if (!articleContent) {
                throw new Error('Method schema is empty');
            }
            return {
                content: [
                    {
                        type: 'text',
                        text: articleContent
                    }
                ]
            };
        }
        catch (error) {
            logger.error(`Error fetching method schema for ${articleUrl}: ${error}`);
            return {
                content: [
                    {
                        type: 'text',
                        text: `Could not fetch method schema: "${error.message}". You should try completing the task without it.`
                    }
                ]
            };
        }
    });
};
//# sourceMappingURL=docs.js.map