import { logger } from '../infra/logger.js';
export const MAX_CONTENT_LENGTH = 10000;
export const DEFAULT_MAX_RESULTS = 10;
const runSemanticSearch = async (toolName, toolParams, maxResults = 20, rerank = false) => {
    const startTime = new Date().getTime();
    const url = new URL(`https://www.wixapis.com/mcp-docs-search/v1/search?maxResults=${maxResults}&rerank=${rerank}`);
    if (toolName === 'SDK') {
        url.searchParams.append('kbName', 'SDK_SCHEMAS_KB_ID');
        url.searchParams.append('kbName', 'SDK_DOCS_KB_ID');
    }
    else if (toolName === 'REST' || toolName === 'BUSINESS_SOLUTIONS') {
        if (toolName === 'REST') {
            url.searchParams.append('kbName', 'REST_METHODS_KB_ID');
        }
        url.searchParams.append('kbName', 'REST_DOCS_KB_ID');
        url.searchParams.append('kbName', 'MCP_REST_RECIPES_KB_ID');
    }
    else if (toolName === 'WDS') {
        url.searchParams.append('kbName', 'WDS_DOCS_KB_ID');
    }
    else if (toolName === 'BUILD_APPS') {
        url.searchParams.append('kbName', 'BUILD_APPS_KB_ID');
    }
    else if (toolName === 'WIX_HEADLESS') {
        url.searchParams.append('kbName', 'HEADLESS_KB_ID');
    }
    for (const [key, value] of Object.entries(toolParams)) {
        url.searchParams.append(key, value);
    }
    logger.log('Running RAG search', url.toString());
    const response = await fetch(url.toString(), {
        headers: {
            'Content-Type': 'application/json',
            'x-time-budget': '180000',
            'x-wix-time-budget': '180000'
        }
    });
    if (!response.ok) {
        logger.error(`Failed to run rag search: ${response.statusText}`);
        throw new Error(`Failed to run rag search: ${response.statusText}`);
    }
    const data = await response.json();
    const endTime = new Date().getTime();
    const timeTaskFormatted = (endTime - startTime) / 1000;
    logger.log('Ran RAG search successfully with params', JSON.stringify(toolParams), timeTaskFormatted, typeof data);
    return data?.results;
};
const getContentFromChunkedContent = (chunkedContent) => {
    let content = '';
    for (const chunk of chunkedContent) {
        if (content.length + chunk.length > MAX_CONTENT_LENGTH) {
            break;
        }
        content += '\n\n---\n\n' + chunk;
    }
    return content;
};
const formatResultsContent = (resultsFromKbs, maxResults, linesInEachResult = undefined) => {
    // First, take the results from all KBs and sort them by overallMatchScore
    const allResults = Object.entries(resultsFromKbs)
        .map(([, { results }]) => results)
        .flat();
    if (allResults.length === 0) {
        throw new Error('No result from search');
    }
    const sortedResults = allResults.sort((a, b) => b.scoresInfo.overallMatchScore - a.scoresInfo.overallMatchScore);
    // Take the top maxResults results
    const topResults = sortedResults.slice(0, maxResults);
    // Concatenate the content of the top results
    const concatenatedContent = topResults
        .map((result) => {
        let newContent = result.entry.content;
        if (linesInEachResult) {
            const totalLines = newContent.split('\n').length;
            const linesToTake = Math.min(linesInEachResult, totalLines);
            newContent = newContent.split('\n').slice(0, linesToTake).join('\n');
            const moreLines = totalLines - linesToTake;
            const moreLinesText = moreLines > 0 ? `\n\n... ${moreLines} more lines ...` : '';
            newContent = `${newContent}${moreLinesText}`;
        }
        return {
            ...result,
            entry: {
                ...result.entry,
                content: newContent
            }
        };
    })
        .map((result) => {
        const content = result.entry.content;
        const chunkedContent = result.entry.chunkedContent;
        if (content.length > MAX_CONTENT_LENGTH) {
            logger.log(`Content is too long, using chunked content`, {
                contentLength: content.length,
                chunkedContentLength: chunkedContent.length
            });
            return getContentFromChunkedContent(chunkedContent);
        }
        return content;
    })
        .join('\n\n---\n\n');
    return concatenatedContent;
};
export const runSemanticSearchAndFormat = async ({ toolName, toolParams, maxResults = DEFAULT_MAX_RESULTS, rerank, linesInEachResult }) => {
    const results = await runSemanticSearch(toolName, toolParams, maxResults, rerank);
    const maxResultsToUse = Math.min(maxResults, DEFAULT_MAX_RESULTS);
    return formatResultsContent(results, maxResultsToUse, linesInEachResult);
};
//# sourceMappingURL=semanticSearch.js.map