import { handleWixAPIResponse } from './tool-utils.js';
import { expect, test, vi, describe, beforeEach } from 'vitest';
// Mock the global fetch function
global.fetch = vi.fn();
function mockHttpClientResponse(data, status = 200, statusText = 'OK', requestId = '') {
    return {
        requestId: '',
        data,
        status,
        statusText,
        headers: {
            'x-wix-request-id': requestId
        },
        config: {},
        request: {}
    };
}
describe('handleWixAPIResponse', () => {
    beforeEach(() => {
        // Reset the mock before each test
        global.fetch.mockClear();
    });
    describe('safeParseJSON', () => {
        test('should parse valid JSON string', async () => {
            const jsonString = '{"key": "value", "number": 123}';
            const result = await handleWixAPIResponse(mockHttpClientResponse(jsonString));
            expect(result).toEqual({ key: 'value', number: 123 });
        });
        test('should return the original string if parsing fails', async () => {
            const invalidJSONString = 'this is not valid json';
            const result = await handleWixAPIResponse(mockHttpClientResponse(invalidJSONString));
            expect(result).toBe(invalidJSONString);
        });
        test('should return an empty string if the response text is empty', async () => {
            global.fetch.mockResolvedValueOnce(new Response('', { status: 200 }));
            const result = await handleWixAPIResponse(mockHttpClientResponse(''));
            expect(result).toBe('');
        });
    });
    test('should return parsed JSON data for a successful response', async () => {
        const mockData = { message: 'Success!' };
        global.fetch.mockResolvedValueOnce(new Response(JSON.stringify(mockData), {
            status: 200,
            statusText: 'OK',
            headers: new Headers({ 'Content-Type': 'application/json' })
        }));
        const result = await handleWixAPIResponse(mockHttpClientResponse(mockData));
        expect(result).toEqual(mockData);
    });
    test('should return the original string if the successful response is not JSON', async () => {
        const mockData = 'This is plain text';
        global.fetch.mockResolvedValueOnce(new Response(mockData, { status: 200, statusText: 'OK' }));
        const result = await handleWixAPIResponse(mockHttpClientResponse(mockData));
        expect(result).toBe(mockData);
    });
    test('should throw an error for a failed response with JSON error details', async () => {
        const mockError = { error: 'Something went wrong', code: 500 };
        const mockRequestId = 'some-request-id';
        await expect(handleWixAPIResponse(mockHttpClientResponse(mockError, 500, 'Internal Server Error', mockRequestId))).rejects.toThrowError([
            'Failed to call Wix API: 500 Internal Server Error.',
            `request id: ${mockRequestId}`,
            '{"error":"Something went wrong","code":500}'
        ].join('\n'));
    });
    test('should throw an error for a failed response with non-JSON error details', async () => {
        const mockError = 'Internal server error occurred.';
        global.fetch.mockResolvedValueOnce(new Response(mockError, {
            status: 503,
            statusText: 'Service Unavailable'
        }));
        await expect(handleWixAPIResponse(mockHttpClientResponse(mockError, 503, 'Service Unavailable'))).rejects.toThrowError(['Failed to call Wix API: 503 Service Unavailable.', mockError].join('\n'));
    });
    test('should include the request ID in the error message if present', async () => {
        const mockError = { message: 'Unauthorized' };
        const mockRequestId = 'another-id';
        global.fetch.mockResolvedValueOnce(new Response(JSON.stringify(mockError), {
            status: 401,
            statusText: 'Unauthorized',
            headers: new Headers({ 'x-wix-request-id': mockRequestId })
        }));
        await expect(handleWixAPIResponse(mockHttpClientResponse(mockError, 401, 'Unauthorized', mockRequestId))).rejects.toThrowError([
            'Failed to call Wix API: 401 Unauthorized.',
            `request id: ${mockRequestId}`,
            '{"message":"Unauthorized"}'
        ].join('\n'));
    });
    test('should return "Not found" in the error message for a 404 with HTML content', async () => {
        const mockHtmlError = '<html><body><h1>404 Not Found</h1></body></html>';
        global.fetch.mockResolvedValueOnce(new Response(mockHtmlError, { status: 404, statusText: 'Not Found' }));
        await expect(handleWixAPIResponse(mockHttpClientResponse(mockHtmlError, 404, 'Not Found'))).rejects.toThrowError(['Failed to call Wix API: 404 Not Found.', 'Not found'].join('\n'));
    });
    test('should include the HTML content in the error message for a 404 without typical HTML structure', async () => {
        const mockNonHtmlError = 'Resource not found on the server.';
        global.fetch.mockResolvedValueOnce(new Response(mockNonHtmlError, { status: 404, statusText: 'Not Found' }));
        await expect(handleWixAPIResponse(mockHttpClientResponse(mockNonHtmlError, 404, 'Not Found'))).rejects.toThrowError(['Failed to call Wix API: 404 Not Found.', mockNonHtmlError].join('\n'));
    });
});
//# sourceMappingURL=tool-utils.spec.js.map