import { v4 as uuidv4 } from 'uuid';
import { captureException, setTags } from '@sentry/node';
import { McpServer } from '@modelcontextprotocol/sdk/server/mcp.js';
import { wixMcpRequestSrc39Evid1607 } from '@wix/bi-logger-api-infra-data/v2';
import { createPanoramaClient } from './infra/panorama.js';
import { createBiLogger } from './infra/bi-logger.js';
import { DEV_ENVIRONMENTS, getEnvironment } from './infra/environment.js';
import { HttpClient } from '@wix/http-client';
import { logger } from './infra/logger.js';
export class WixMcpServer extends McpServer {
    serverInfo;
    biLogger;
    nodeEnv;
    sessionId;
    getUserId;
    getClientName;
    constructor(serverInfo, options, nodeEnv) {
        super(serverInfo, options);
        this.serverInfo = serverInfo;
        this.sessionId = uuidv4();
        this.nodeEnv = getEnvironment(nodeEnv);
        this.biLogger = createBiLogger({
            _client_id: this.sessionId
        });
        logger.log(`WixMcpServer created with sessionId: ${this.sessionId}`);
    }
    setUserIdGetter(getUserId) {
        this.getUserId = getUserId;
    }
    setClientNameGetter(getClientName) {
        this.getClientName = getClientName;
    }
    tool(...args) {
        const cbIndex = args.findIndex((arg) => typeof arg === 'function');
        if (cbIndex !== -1) {
            const originalCb = args[cbIndex];
            const toolName = args[0];
            const isDevEnvironment = DEV_ENVIRONMENTS.includes(this.nodeEnv);
            const wrappedCb = async (...cbArgs) => {
                setTags({
                    panoramaSessionId: this.sessionId
                });
                const panorama = createPanoramaClient({
                    environment: this.nodeEnv,
                    sessionId: this.sessionId,
                    componentId: toolName,
                    uuid: this.getUserId?.(),
                    serverInfo: this.serverInfo
                });
                const toolInvocationId = uuidv4();
                const httpClient = new HttpClient({
                    headers: {
                        'x-wix-mcp': `execution-id=${toolInvocationId}`
                    }
                });
                const argsBeforeExtra = cbArgs.slice(0, cbArgs.length - 1);
                const extra = cbArgs[cbArgs.length - 1];
                const wrappedExtra = {
                    ...extra,
                    panorama: panorama.createClientForComponent(),
                    httpClient
                };
                if (!isDevEnvironment) {
                    panorama.transaction(toolName).start({
                        toolInvocationId,
                        params: JSON.stringify(argsBeforeExtra)
                    });
                }
                const startTime = performance.now();
                let toolSucceeded, errorBody;
                try {
                    const cbResult = await originalCb(...argsBeforeExtra, wrappedExtra);
                    if (!isDevEnvironment) {
                        panorama.transaction(toolName).finish({ toolInvocationId });
                    }
                    toolSucceeded = true;
                    return cbResult;
                }
                catch (e) {
                    toolSucceeded = false;
                    errorBody = e.message;
                    if (!isDevEnvironment) {
                        panorama.errorMonitor().reportError(e);
                        captureException(e, {
                            tags: {
                                componentId: toolName,
                                toolName
                            }
                        });
                    }
                    return {
                        isError: true,
                        content: [{ type: 'text', text: e.message }]
                    };
                }
                finally {
                    const endTime = performance.now();
                    const duration = Math.round(endTime - startTime);
                    const clientName = this.server.getClientVersion()?.name;
                    if (!isDevEnvironment) {
                        if (this.getUserId) {
                            const userId = this.getUserId();
                            this.biLogger.updateDefaults({
                                _uuid: userId
                            });
                        }
                        this.biLogger.report(wixMcpRequestSrc39Evid1607({
                            clientName: this.getClientName?.() || clientName,
                            duration,
                            errorBody,
                            toolInvocationId,
                            toolName,
                            params: JSON.stringify(argsBeforeExtra),
                            origin: this.nodeEnv,
                            sessionId: this.sessionId,
                            executionResult: toolSucceeded ? 'Success' : 'Error'
                        }));
                    }
                }
            };
            args[cbIndex] = wrappedCb;
        }
        return super.tool.apply(this, args);
    }
}
//# sourceMappingURL=wix-mcp-server.js.map